@@ -103,6 +103,14 @@ class MIDILikeEncoding(MIDITokenizer):
                     previous_tick += round(rest_pos_temp * ticks_per_sample)
                     rest_pos -= rest_pos_temp
 
+                # Adds an additional time shift if needed
+                if rest_pos > 0:
+                    time_shift = round(rest_pos * ticks_per_sample)
+                    index = np.argmin(np.abs([ticks - time_shift for ticks in
+                                              self.durations_ticks[self.current_midi_metadata['time_division']]]))
+                    events.append(Event(type_='Time-Shift', time=previous_tick,
+                                        value='.'.join(map(str, self.durations[index])), desc=f'{time_shift} ticks'))
+
             # Time shift
             else:
                 time_shift = event.time - previous_tick
@@ -121,7 +129,7 @@ class MIDILikeEncoding(MIDITokenizer):
 
         events.sort(key=lambda x: (x.time, self._order(x)))
 
-        return self._events_to_tokens(events)
+        return self.events_to_tokens(events)
 
     def tokens_to_track(self, tokens: List[int], time_division: Optional[int] = TIME_DIVISION,
                         program: Optional[Tuple[int, bool]] = (0, False), default_duration: int = None) \
@@ -136,7 +144,7 @@ class MIDILikeEncoding(MIDITokenizer):
         :return: the miditoolkit instrument object and tempo changes
         """
         ticks_per_sample = time_division // max(self.beat_res.values())
-        events = self._tokens_to_events(tokens)
+        events = self.tokens_to_events(tokens)
 
         max_duration = (self.durations[-1][0] + self.durations[-1][1]) * time_division
         name = 'Drums' if program[1] else MIDI_INSTRUMENTS[program[0]]['name']
@@ -261,7 +269,7 @@ class MIDILikeEncoding(MIDITokenizer):
                 dic['Tempo'] += ['Chord']
 
         if self.additional_tokens['Rest']:
-            dic['Rest'] = ['Rest', 'Note-On']
+            dic['Rest'] = ['Rest', 'Note-On', 'Time-Shift']
             if self.additional_tokens['Chord']:
                 dic['Rest'] += ['Chord']
             dic['Note-Off'] += ['Rest']
