@@ -63,25 +63,20 @@ class REMIEncoding(MIDITokenizer):
                     rest_beat, rest_pos = divmod(note.start-previous_tick, self.current_midi_metadata['time_division'])
                     rest_beat = min(rest_beat, max([r[0] for r in self.rests]))
                     rest_pos = round(rest_pos / ticks_per_sample)
-                    rest_tick = previous_tick  # untouched tick value to the order is not messed after sorting
 
                     if rest_beat > 0:
-                        events.append(Event(type_='Rest', time=rest_tick, value=f'{rest_beat}.0',
+                        events.append(Event(type_='Rest', time=previous_note_end, value=f'{rest_beat}.0',
                                             desc=f'{rest_beat}.0'))
                         previous_tick += rest_beat * self.current_midi_metadata['time_division']
 
                     while rest_pos >= self.rests[0][1]:
                         rest_pos_temp = min([r[1] for r in self.rests], key=lambda x: abs(x - rest_pos))
-                        events.append(Event(type_='Rest', time=rest_tick, value=f'0.{rest_pos_temp}',
+                        events.append(Event(type_='Rest', time=previous_note_end, value=f'0.{rest_pos_temp}',
                                             desc=f'0.{rest_pos_temp}'))
                         previous_tick += round(rest_pos_temp * ticks_per_sample)
                         rest_pos -= rest_pos_temp
 
-                    previous_tick += round(rest_pos * ticks_per_sample)  # remaining rest pos not represented
-                    current_bar_temp = previous_tick // ticks_per_bar
-                    if current_bar != current_bar_temp:  # if the rest crossed one or several new bars
-                        current_bar = current_bar_temp
-                        events.append(Event(type_='Bar', time=previous_tick, value=None, desc=0))
+                    current_bar = previous_tick // ticks_per_bar
 
                 # Bar
                 nb_new_bars = note.start // ticks_per_bar - current_bar
@@ -126,7 +121,7 @@ class REMIEncoding(MIDITokenizer):
 
         events.sort(key=lambda x: (x.time, self._order(x)))
 
-        return self._events_to_tokens(events)
+        return self.events_to_tokens(events)
 
     def tokens_to_track(self, tokens: List[int], time_division: Optional[int] = TIME_DIVISION,
                         program: Optional[Tuple[int, bool]] = (0, False)) -> Tuple[Instrument, List[TempoChange]]:
@@ -139,7 +134,7 @@ class REMIEncoding(MIDITokenizer):
         """
         assert time_division % max(self.beat_res.values()) == 0, \
             f'Invalid time division, please give one divisible by {max(self.beat_res.values())}'
-        events = self._tokens_to_events(tokens)
+        events = self.tokens_to_events(tokens)
 
         ticks_per_sample = time_division // max(self.beat_res.values())
         ticks_per_bar = time_division * 4
@@ -159,9 +154,7 @@ class REMIEncoding(MIDITokenizer):
                 if current_tick < previous_note_end:  # if in case successive rest happen
                     current_tick = previous_note_end
                 current_tick += beat * time_division + pos * ticks_per_sample
-                current_bar_temp = current_tick // ticks_per_bar
-                if current_bar_temp > current_bar + 1:
-                    current_bar = current_bar_temp - 1
+                current_bar = current_tick // ticks_per_bar
             elif event.type == 'Position':
                 current_tick = current_bar * ticks_per_bar + int(event.value) * ticks_per_sample
             elif event.type == 'Tempo':
@@ -299,7 +292,7 @@ class REMIEncoding(MIDITokenizer):
                     else:
                         current_pitches.append(int(token_value))
                 elif token_type == 'Position':
-                    if int(token_value) <= current_pos:
+                    if int(token_value) <= current_pos and previous_type != 'Rest':
                         err += 1  # token position value <= to the current position
                     else:
                         current_pos = int(token_value)
